@@ -1,4 +1,4 @@
-use crate::{ComplexSelector, Property};
+use crate::{ComplexSelector, Property, Tokens};
 use swc_common::{ast_node, Span};
 
 #[ast_node("StyleRule")]
@@ -11,5 +11,13 @@ pub struct StyleRule {
 #[ast_node("DeclBlock")]
 pub struct DeclBlock {
     pub span: Span,
-    pub properties: Vec<Property>,
+    pub items: Vec<DeclBlockItem>,
+}
+
+#[ast_node]
+pub enum DeclBlockItem {
+    #[tag("Tokens")]
+    Invalid(Tokens),
+    #[tag("Property")]
+    Property(Property),
 }
